@@ -23,7 +23,7 @@ class TestUtil(unittest.TestCase):
 
         # Assert
         for i, tol in enumerate(tolerances):
-            assert 3*result[i] < tol
+            assert 3 * result[i] < tol
 
     def test_probability_med_for_tolerance(self):
         # Arrange
@@ -37,14 +37,20 @@ class TestUtil(unittest.TestCase):
 
         # Assert
         for i, tol in enumerate(tolerances):
-            assert 3*result[i] < tol
+            assert 3 * result[i] < tol
+
 
 class TestRandomSetups(unittest.TestCase):
     def test_random_map(self):
         for d in ['normal', 'uniform', None]:
             for r in [True, False]:
-                A = mdu.createRandomLinearMap(dim_input=1,
-                                              dim_output=2,
-                                              dist=d,
-                                              repeated=r)
-                assert A is not None
\ No newline at end of file
+                for _dim_in in [1, 5, 10]:
+                    A = mdu.createRandomLinearMap(dim_input=_dim_in,
+                                                  dim_output=10,
+                                                  dist=d,
+                                                  repeated=r)
+                    assert A is not None
+                    if not r:
+                        assert np.linalg.matrix_rank(A) == _dim_in
+                    else:
+                        assert np.linalg.matrix_rank(A) == 1
